﻿using Infragistics.Controls.Schedules;
using Infragistics.Controls.Schedules.Primitives;
using Infragistics.Windows;
using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;

namespace XamSchedule_ActivityDialog
{
    /// <summary>
    /// MainWindow.xaml の相互作用ロジック
    /// </summary>
    public partial class MainWindow : Window
    {
        public MainWindow()
        {
            InitializeComponent();

            DataContext = new MainWindowViewModel();
        }
    }

    public sealed class MainWindowViewModel : INotifyPropertyChanged
    {
        private ObservableCollection<Resource> _resources;

        public ObservableCollection<Resource> Resources
        {
            get { return _resources; }
            set
            {
                _resources = value;
                NotifyPropertyChanged("Resources");
            }
        }

        private ObservableCollection<ResourceCalendar> _resourceCalendars;

        public ObservableCollection<ResourceCalendar> ResourceCalendars
        {
            get { return _resourceCalendars; }
            set
            {
                _resourceCalendars = value;
                NotifyPropertyChanged("ResourceCalendars");
            }
        }

        private ObservableCollection<MyAppointment> _appointments;

        public ObservableCollection<MyAppointment> Appointments
        {
            get { return _appointments; }
            set
            {
                _appointments = value;
                NotifyPropertyChanged("Appointments");
            }
        }


        public MainWindowViewModel()
        {
            Resources = new ObservableCollection<Resource>();
            var res1 = new Resource() { Id = "Resouce1", Name = "Resouce1" };
            Resources.Add(res1);

            ResourceCalendars = new ObservableCollection<ResourceCalendar>();
            var cal1 = new ResourceCalendar() { Id = "ResourceCalendar1", Name = "ResourceCalendar1", OwningResourceId = "Resouce1" };
            ResourceCalendars.Add(cal1);

            Appointments = new ObservableCollection<MyAppointment>();
            var app1 = new MyAppointment()
            {
                Id = "Appointment1",
                OwningResourceId = "Resouce1",
                OwningCalendarId = "ResourceCalendar1",
                Subject = "Appointment1",
                Location = "Location1",
                Start = DateTime.Today.AddHours(10),
                End = DateTime.Today.AddHours(12),
                StartTimeZoneId = "Tokyo Standard Time",
                EndTimeZoneId = "Tokyo Standard Time",
                MyValue = "test1"

            };
            var app2 = new MyAppointment()
            {
                Id = "Appointment2",
                OwningResourceId = "Resouce1",
                OwningCalendarId = "ResourceCalendar1",
                Subject = "Appointment2",
                Location = "Location2",
                Start = DateTime.Today.AddDays(2).AddHours(5),
                End = DateTime.Today.AddDays(2).AddHours(10),
                StartTimeZoneId = "Tokyo Standard Time",
                EndTimeZoneId = "Tokyo Standard Time",
                MyValue = "test2"
            };
            Appointments.Add(app1);
            Appointments.Add(app2);
        }

        public event PropertyChangedEventHandler PropertyChanged;

        private void NotifyPropertyChanged(String info)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(info));
            }
        }
    }

    public class MyAppointment : Appointment
    {
        private string _myValue;
        public string MyValue
        {
            get { return _myValue; }
            set { this.SetField(ref _myValue, value, "MyValue"); }
        }
    }
}
